@@ -3,16 +3,16 @@ Integration tests for authentication.
 
 Unit tests for auth classes also exist in tests/test_auth.py
 """
-import asyncio
 import hashlib
 import os
 import threading
 import typing
+from urllib.request import parse_keqv_list
 
+import anyio
 import pytest
 
 import httpx
-from httpx import URL, Auth, BasicAuth, DigestAuth, ProtocolError, Request, Response
 
 from ..common import FIXTURES_DIR
 
@@ -74,10 +74,10 @@ class DigestApp:
         headers = {
             "www-authenticate": f'Digest realm="httpx@example.org", {challenge_str}',
         }
-        return Response(401, headers=headers)
+        return httpx.Response(401, headers=headers)
 
 
-class RepeatAuth(Auth):
+class RepeatAuth(httpx.Auth):
     """
     A mock authentication scheme that requires clients to send
     the request a fixed number of times, and then send a last request containing
@@ -90,7 +90,9 @@ class RepeatAuth(Auth):
     def __init__(self, repeat: int):
         self.repeat = repeat
 
-    def auth_flow(self, request: Request) -> typing.Generator[Request, Response, None]:
+    def auth_flow(
+        self, request: httpx.Request
+    ) -> typing.Generator[httpx.Request, httpx.Response, None]:
         nonces = []
 
         for index in range(self.repeat):
@@ -103,7 +105,7 @@ class RepeatAuth(Auth):
         yield request
 
 
-class ResponseBodyAuth(Auth):
+class ResponseBodyAuth(httpx.Auth):
     """
     A mock authentication scheme that requires clients to send an 'Authorization'
     header, then send back the contents of the response in the 'Authorization'
@@ -112,10 +114,12 @@ class ResponseBodyAuth(Auth):
 
     requires_response_body = True
 
-    def __init__(self, token):
+    def __init__(self, token: str) -> None:
         self.token = token
 
-    def auth_flow(self, request: Request) -> typing.Generator[Request, Response, None]:
+    def auth_flow(
+        self, request: httpx.Request
+    ) -> typing.Generator[httpx.Request, httpx.Response, None]:
         request.headers["Authorization"] = self.token
         response = yield request
         data = response.text
@@ -123,7 +127,7 @@ class ResponseBodyAuth(Auth):
         yield request
 
 
-class SyncOrAsyncAuth(Auth):
+class SyncOrAsyncAuth(httpx.Auth):
     """
     A mock authentication scheme that uses a different implementation for the
     sync and async cases.
@@ -131,43 +135,43 @@ class SyncOrAsyncAuth(Auth):
 
     def __init__(self) -> None:
         self._lock = threading.Lock()
-        self._async_lock = asyncio.Lock()
+        self._async_lock = anyio.Lock()
 
     def sync_auth_flow(
-        self, request: Request
-    ) -> typing.Generator[Request, Response, None]:
+        self, request: httpx.Request
+    ) -> typing.Generator[httpx.Request, httpx.Response, None]:
         with self._lock:
             request.headers["Authorization"] = "sync-auth"
         yield request
 
     async def async_auth_flow(
-        self, request: Request
-    ) -> typing.AsyncGenerator[Request, Response]:
+        self, request: httpx.Request
+    ) -> typing.AsyncGenerator[httpx.Request, httpx.Response]:
         async with self._async_lock:
             request.headers["Authorization"] = "async-auth"
         yield request
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_basic_auth() -> None:
     url = "https://example.org/"
-    auth = ("tomchristie", "password123")
+    auth = ("user", "password123")
     app = App()
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
         response = await client.get(url, auth=auth)
 
     assert response.status_code == 200
-    assert response.json() == {"auth": "Basic dG9tY2hyaXN0aWU6cGFzc3dvcmQxMjM="}
+    assert response.json() == {"auth": "Basic dXNlcjpwYXNzd29yZDEyMw=="}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_basic_auth_with_stream() -> None:
     """
     See: https://github.com/encode/httpx/pull/1312
     """
     url = "https://example.org/"
-    auth = ("tomchristie", "password123")
+    auth = ("user", "password123")
     app = App()
 
     async with httpx.AsyncClient(
@@ -177,25 +181,25 @@ async def test_basic_auth_with_stream() -> None:
             await response.aread()
 
     assert response.status_code == 200
-    assert response.json() == {"auth": "Basic dG9tY2hyaXN0aWU6cGFzc3dvcmQxMjM="}
+    assert response.json() == {"auth": "Basic dXNlcjpwYXNzd29yZDEyMw=="}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_basic_auth_in_url() -> None:
-    url = "https://tomchristie:password123@example.org/"
+    url = "https://user:password123@example.org/"
     app = App()
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
         response = await client.get(url)
 
     assert response.status_code == 200
-    assert response.json() == {"auth": "Basic dG9tY2hyaXN0aWU6cGFzc3dvcmQxMjM="}
+    assert response.json() == {"auth": "Basic dXNlcjpwYXNzd29yZDEyMw=="}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_basic_auth_on_session() -> None:
     url = "https://example.org/"
-    auth = ("tomchristie", "password123")
+    auth = ("user", "password123")
     app = App()
 
     async with httpx.AsyncClient(
@@ -204,15 +208,15 @@ async def test_basic_auth_on_session() -> None:
         response = await client.get(url)
 
     assert response.status_code == 200
-    assert response.json() == {"auth": "Basic dG9tY2hyaXN0aWU6cGFzc3dvcmQxMjM="}
+    assert response.json() == {"auth": "Basic dXNlcjpwYXNzd29yZDEyMw=="}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_custom_auth() -> None:
     url = "https://example.org/"
     app = App()
 
-    def auth(request: Request) -> Request:
+    def auth(request: httpx.Request) -> httpx.Request:
         request.headers["Authorization"] = "Token 123"
         return request
 
@@ -223,7 +227,7 @@ async def test_custom_auth() -> None:
     assert response.json() == {"auth": "Token 123"}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_netrc_auth() -> None:
     os.environ["NETRC"] = str(FIXTURES_DIR / ".netrc")
     url = "http://netrcexample.org"
@@ -238,7 +242,7 @@ async def test_netrc_auth() -> None:
     }
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_auth_header_has_priority_over_netrc() -> None:
     os.environ["NETRC"] = str(FIXTURES_DIR / ".netrc")
     url = "http://netrcexample.org"
@@ -251,7 +255,7 @@ async def test_auth_header_has_priority_over_netrc() -> None:
     assert response.json() == {"auth": "Override"}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_trust_env_auth() -> None:
     os.environ["NETRC"] = str(FIXTURES_DIR / ".netrc")
     url = "http://netrcexample.org"
@@ -276,10 +280,10 @@ async def test_trust_env_auth() -> None:
     }
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_auth_disable_per_request() -> None:
     url = "https://example.org/"
-    auth = ("tomchristie", "password123")
+    auth = ("user", "password123")
     app = App()
 
     async with httpx.AsyncClient(
@@ -294,11 +298,11 @@ async def test_auth_disable_per_request() -> None:
 def test_auth_hidden_url() -> None:
     url = "http://example-username:example-password@example.org/"
     expected = "URL('http://example-username:[secure]@example.org/')"
-    assert url == URL(url)
-    assert expected == repr(URL(url))
+    assert url == httpx.URL(url)
+    assert expected == repr(httpx.URL(url))
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_auth_hidden_header() -> None:
     url = "https://example.org/"
     auth = ("example-username", "example-password")
@@ -310,23 +314,23 @@ async def test_auth_hidden_header() -> None:
     assert "'authorization': '[secure]'" in str(response.request.headers)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_auth_property() -> None:
     app = App()
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
         assert client.auth is None
 
-        client.auth = ("tomchristie", "password123")  # type: ignore
-        assert isinstance(client.auth, BasicAuth)
+        client.auth = ("user", "password123")  # type: ignore
+        assert isinstance(client.auth, httpx.BasicAuth)
 
         url = "https://example.org/"
         response = await client.get(url)
         assert response.status_code == 200
-        assert response.json() == {"auth": "Basic dG9tY2hyaXN0aWU6cGFzc3dvcmQxMjM="}
+        assert response.json() == {"auth": "Basic dXNlcjpwYXNzd29yZDEyMw=="}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_auth_invalid_type() -> None:
     app = App()
 
@@ -344,10 +348,10 @@ async def test_auth_invalid_type() -> None:
             client.auth = "not a tuple, not a callable"  # type: ignore
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_returns_no_auth_if_no_digest_header_in_response() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = App()
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -360,7 +364,7 @@ async def test_digest_auth_returns_no_auth_if_no_digest_header_in_response() ->
 
 def test_digest_auth_returns_no_auth_if_alternate_auth_scheme() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     auth_header = "Token ..."
     app = App(auth_header=auth_header, status_code=401)
 
@@ -372,10 +376,10 @@ def test_digest_auth_returns_no_auth_if_alternate_auth_scheme() -> None:
     assert len(response.history) == 0
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_200_response_including_digest_auth_header() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     auth_header = 'Digest realm="realm@host.com",qop="auth",nonce="abc",opaque="xyz"'
     app = App(auth_header=auth_header, status_code=200)
 
@@ -387,10 +391,10 @@ async def test_digest_auth_200_response_including_digest_auth_header() -> None:
     assert len(response.history) == 0
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_401_response_without_digest_auth_header() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = App(auth_header="", status_code=401)
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -414,12 +418,12 @@ async def test_digest_auth_401_response_without_digest_auth_header() -> None:
         ("SHA-512-SESS", 64, 128),
     ],
 )
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth(
     algorithm: str, expected_hash_length: int, expected_response_length: int
 ) -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(algorithm=algorithm)
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -428,14 +432,14 @@ async def test_digest_auth(
     assert response.status_code == 200
     assert len(response.history) == 1
 
-    authorization = typing.cast(dict, response.json())["auth"]
+    authorization = typing.cast(typing.Dict[str, typing.Any], response.json())["auth"]
     scheme, _, fields = authorization.partition(" ")
     assert scheme == "Digest"
 
     response_fields = [field.strip() for field in fields.split(",")]
     digest_data = dict(field.split("=") for field in response_fields)
 
-    assert digest_data["username"] == '"tomchristie"'
+    assert digest_data["username"] == '"user"'
     assert digest_data["realm"] == '"httpx@example.org"'
     assert "nonce" in digest_data
     assert digest_data["uri"] == '"/"'
@@ -447,10 +451,10 @@ async def test_digest_auth(
     assert len(digest_data["cnonce"]) == 16 + 2
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_no_specified_qop() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(qop="")
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -459,7 +463,7 @@ async def test_digest_auth_no_specified_qop() -> None:
     assert response.status_code == 200
     assert len(response.history) == 1
 
-    authorization = typing.cast(dict, response.json())["auth"]
+    authorization = typing.cast(typing.Dict[str, typing.Any], response.json())["auth"]
     scheme, _, fields = authorization.partition(" ")
     assert scheme == "Digest"
 
@@ -469,7 +473,7 @@ async def test_digest_auth_no_specified_qop() -> None:
     assert "qop" not in digest_data
     assert "nc" not in digest_data
     assert "cnonce" not in digest_data
-    assert digest_data["username"] == '"tomchristie"'
+    assert digest_data["username"] == '"user"'
     assert digest_data["realm"] == '"httpx@example.org"'
     assert len(digest_data["nonce"]) == 64 + 2  # extra quotes
     assert digest_data["uri"] == '"/"'
@@ -479,10 +483,10 @@ async def test_digest_auth_no_specified_qop() -> None:
 
 
 @pytest.mark.parametrize("qop", ("auth, auth-int", "auth,auth-int", "unknown,auth"))
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_qop_including_spaces_and_auth_returns_auth(qop: str) -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(qop=qop)
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -492,10 +496,10 @@ async def test_digest_auth_qop_including_spaces_and_auth_returns_auth(qop: str)
     assert len(response.history) == 1
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_qop_auth_int_not_implemented() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(qop="auth-int")
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -503,21 +507,21 @@ async def test_digest_auth_qop_auth_int_not_implemented() -> None:
             await client.get(url, auth=auth)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_qop_must_be_auth_or_auth_int() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(qop="not-auth")
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
-        with pytest.raises(ProtocolError):
+        with pytest.raises(httpx.ProtocolError):
             await client.get(url, auth=auth)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_incorrect_credentials() -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp(send_response_after_attempt=2)
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
@@ -527,6 +531,62 @@ async def test_digest_auth_incorrect_credentials() -> None:
     assert len(response.history) == 1
 
 
+@pytest.mark.anyio
+async def test_digest_auth_reuses_challenge() -> None:
+    url = "https://example.org/"
+    auth = httpx.DigestAuth(username="user", password="password123")
+    app = DigestApp()
+
+    async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
+        response_1 = await client.get(url, auth=auth)
+        response_2 = await client.get(url, auth=auth)
+
+        assert response_1.status_code == 200
+        assert response_2.status_code == 200
+
+        assert len(response_1.history) == 1
+        assert len(response_2.history) == 0
+
+
+@pytest.mark.anyio
+async def test_digest_auth_resets_nonce_count_after_401() -> None:
+    url = "https://example.org/"
+    auth = httpx.DigestAuth(username="user", password="password123")
+    app = DigestApp()
+
+    async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
+        response_1 = await client.get(url, auth=auth)
+        assert response_1.status_code == 200
+        assert len(response_1.history) == 1
+
+        first_nonce = parse_keqv_list(
+            response_1.request.headers["Authorization"].split(", ")
+        )["nonce"]
+        first_nc = parse_keqv_list(
+            response_1.request.headers["Authorization"].split(", ")
+        )["nc"]
+
+        # with this we now force a 401 on a subsequent (but initial) request
+        app.send_response_after_attempt = 2
+
+        # we expect the client again to try to authenticate, i.e. the history length must be 1
+        response_2 = await client.get(url, auth=auth)
+        assert response_2.status_code == 200
+        assert len(response_2.history) == 1
+
+        second_nonce = parse_keqv_list(
+            response_2.request.headers["Authorization"].split(", ")
+        )["nonce"]
+        second_nc = parse_keqv_list(
+            response_2.request.headers["Authorization"].split(", ")
+        )["nc"]
+
+    assert first_nonce != second_nonce  # ensures that the auth challenge was reset
+    assert (
+        first_nc == second_nc
+    )  # ensures the nonce count is reset when the authentication failed
+
+
 @pytest.mark.parametrize(
     "auth_header",
     [
@@ -534,16 +594,16 @@ async def test_digest_auth_incorrect_credentials() -> None:
         'Digest realm="httpx@example.org", qop="auth,au',  # malformed fields list
     ],
 )
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_async_digest_auth_raises_protocol_error_on_malformed_header(
     auth_header: str,
 ) -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = App(auth_header=auth_header, status_code=401)
 
     async with httpx.AsyncClient(transport=httpx.MockTransport(app)) as client:
-        with pytest.raises(ProtocolError):
+        with pytest.raises(httpx.ProtocolError):
             await client.get(url, auth=auth)
 
 
@@ -558,15 +618,15 @@ def test_sync_digest_auth_raises_protocol_error_on_malformed_header(
     auth_header: str,
 ) -> None:
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = App(auth_header=auth_header, status_code=401)
 
     with httpx.Client(transport=httpx.MockTransport(app)) as client:
-        with pytest.raises(ProtocolError):
+        with pytest.raises(httpx.ProtocolError):
             client.get(url, auth=auth)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_async_auth_history() -> None:
     """
     Test that intermediate requests sent as part of an authentication flow
@@ -620,27 +680,27 @@ def test_sync_auth_history() -> None:
 
 
 class ConsumeBodyTransport(httpx.MockTransport):
-    async def handle_async_request(self, request: Request) -> Response:
+    async def handle_async_request(self, request: httpx.Request) -> httpx.Response:
         assert isinstance(request.stream, httpx.AsyncByteStream)
         [_ async for _ in request.stream]
         return self.handler(request)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_digest_auth_unavailable_streaming_body():
     url = "https://example.org/"
-    auth = DigestAuth(username="tomchristie", password="password123")
+    auth = httpx.DigestAuth(username="user", password="password123")
     app = DigestApp()
 
-    async def streaming_body():
-        yield b"Example request body"  # pragma: nocover
+    async def streaming_body() -> typing.AsyncIterator[bytes]:
+        yield b"Example request body"  # pragma: no cover
 
     async with httpx.AsyncClient(transport=ConsumeBodyTransport(app)) as client:
         with pytest.raises(httpx.StreamConsumed):
             await client.post(url, content=streaming_body(), auth=auth)
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_async_auth_reads_response_body() -> None:
     """
     Test that we can read the response body in an auth flow if `requires_response_body`
@@ -673,7 +733,7 @@ def test_sync_auth_reads_response_body() -> None:
     assert response.json() == {"auth": '{"auth": "xyz"}'}
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_async_auth() -> None:
     """
     Test that we can use an auth implementation specific to the async case, to
