@@ -1,11 +1,11 @@
 import json
 import pickle
+import typing
 
 import chardet
 import pytest
 
 import httpx
-from httpx._compat import brotli
 
 
 class StreamingBody:
@@ -14,12 +14,12 @@ class StreamingBody:
         yield b"world!"
 
 
-def streaming_body():
+def streaming_body() -> typing.Iterator[bytes]:
     yield b"Hello, "
     yield b"world!"
 
 
-async def async_streaming_body():
+async def async_streaming_body() -> typing.AsyncIterator[bytes]:
     yield b"Hello, "
     yield b"world!"
 
@@ -331,7 +331,7 @@ def test_empty_read():
     assert response.is_closed
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aread():
     response = httpx.Response(
         200,
@@ -350,7 +350,7 @@ async def test_aread():
     assert response.is_closed
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_empty_aread():
     response = httpx.Response(200)
 
@@ -396,7 +396,7 @@ def test_iter_raw_with_chunksize():
 
 
 def test_iter_raw_doesnt_return_empty_chunks():
-    def streaming_body_with_empty_chunks():
+    def streaming_body_with_empty_chunks() -> typing.Iterator[bytes]:
         yield b"Hello, "
         yield b""
         yield b"world!"
@@ -449,7 +449,7 @@ def test_iter_raw_increments_updates_counter():
         num_downloaded = response.num_bytes_downloaded
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_raw():
     response = httpx.Response(200, content=async_streaming_body())
 
@@ -459,7 +459,7 @@ async def test_aiter_raw():
     assert raw == b"Hello, world!"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_raw_with_chunksize():
     response = httpx.Response(200, content=async_streaming_body())
 
@@ -477,7 +477,7 @@ async def test_aiter_raw_with_chunksize():
     assert parts == [b"Hello, world!"]
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_raw_on_sync():
     response = httpx.Response(
         200,
@@ -488,7 +488,7 @@ async def test_aiter_raw_on_sync():
         [part async for part in response.aiter_raw()]
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aclose_on_sync():
     response = httpx.Response(
         200,
@@ -499,7 +499,7 @@ async def test_aclose_on_sync():
         await response.aclose()
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_raw_increments_updates_counter():
     response = httpx.Response(200, content=async_streaming_body())
 
@@ -539,7 +539,7 @@ def test_iter_bytes_with_empty_response():
 
 
 def test_iter_bytes_doesnt_return_empty_chunks():
-    def streaming_body_with_empty_chunks():
+    def streaming_body_with_empty_chunks() -> typing.Iterator[bytes]:
         yield b"Hello, "
         yield b""
         yield b"world!"
@@ -551,7 +551,7 @@ def test_iter_bytes_doesnt_return_empty_chunks():
     assert parts == [b"Hello, ", b"world!"]
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_bytes():
     response = httpx.Response(
         200,
@@ -564,7 +564,7 @@ async def test_aiter_bytes():
     assert content == b"Hello, world!"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_bytes_with_chunk_size():
     response = httpx.Response(200, content=async_streaming_body())
     parts = [part async for part in response.aiter_bytes(chunk_size=5)]
@@ -605,7 +605,7 @@ def test_iter_text_with_chunk_size():
     assert parts == ["Hello, world!"]
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_text():
     response = httpx.Response(
         200,
@@ -618,7 +618,7 @@ async def test_aiter_text():
     assert content == "Hello, world!"
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_text_with_chunk_size():
     response = httpx.Response(200, content=b"Hello, world!")
     parts = [part async for part in response.aiter_text(chunk_size=5)]
@@ -642,7 +642,7 @@ def test_iter_lines():
     assert content == ["Hello,\n", "world!"]
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_aiter_lines():
     response = httpx.Response(
         200,
@@ -671,7 +671,7 @@ def test_sync_streaming_response():
     assert response.is_closed
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_async_streaming_response():
     response = httpx.Response(
         200,
@@ -702,7 +702,7 @@ def test_cannot_read_after_stream_consumed():
         response.read()
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_cannot_aread_after_stream_consumed():
     response = httpx.Response(
         200,
@@ -728,7 +728,7 @@ def test_cannot_read_after_response_closed():
         response.read()
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_cannot_aread_after_response_closed():
     response = httpx.Response(
         200,
@@ -740,7 +740,7 @@ async def test_cannot_aread_after_response_closed():
         await response.aread()
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_elapsed_not_available_until_closed():
     response = httpx.Response(
         200,
@@ -862,20 +862,19 @@ def test_link_headers(headers, expected):
 @pytest.mark.parametrize("header_value", (b"deflate", b"gzip", b"br"))
 def test_decode_error_with_request(header_value):
     headers = [(b"Content-Encoding", header_value)]
-    body = b"test 123"
-    compressed_body = brotli.compress(body)[3:]
+    broken_compressed_body = b"xxxxxxxxxxxxxx"
     with pytest.raises(httpx.DecodingError):
         httpx.Response(
             200,
             headers=headers,
-            content=compressed_body,
+            content=broken_compressed_body,
         )
 
     with pytest.raises(httpx.DecodingError):
         httpx.Response(
             200,
             headers=headers,
-            content=compressed_body,
+            content=broken_compressed_body,
             request=httpx.Request("GET", "https://www.example.org/"),
         )
 
@@ -883,10 +882,9 @@ def test_decode_error_with_request(header_value):
 @pytest.mark.parametrize("header_value", (b"deflate", b"gzip", b"br"))
 def test_value_error_without_request(header_value):
     headers = [(b"Content-Encoding", header_value)]
-    body = b"test 123"
-    compressed_body = brotli.compress(body)[3:]
+    broken_compressed_body = b"xxxxxxxxxxxxxx"
     with pytest.raises(httpx.DecodingError):
-        httpx.Response(200, headers=headers, content=compressed_body)
+        httpx.Response(200, headers=headers, content=broken_compressed_body)
 
 
 def test_response_with_unset_request():
@@ -915,16 +913,16 @@ def test_cannot_access_unset_request():
 
 
 def test_generator_with_transfer_encoding_header():
-    def content():
-        yield b"test 123"  # pragma: nocover
+    def content() -> typing.Iterator[bytes]:
+        yield b"test 123"  # pragma: no cover
 
     response = httpx.Response(200, content=content())
     assert response.headers == {"Transfer-Encoding": "chunked"}
 
 
 def test_generator_with_content_length_header():
-    def content():
-        yield b"test 123"  # pragma: nocover
+    def content() -> typing.Iterator[bytes]:
+        yield b"test 123"  # pragma: no cover
 
     headers = {"Content-Length": "8"}
     response = httpx.Response(200, content=content(), headers=headers)
@@ -949,7 +947,7 @@ def test_response_picklable():
     assert pickle_response.history == []
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_response_async_streaming_picklable():
     response = httpx.Response(200, content=async_streaming_body())
     pickle_response = pickle.loads(pickle.dumps(response))
