@@ -1,12 +1,13 @@
 import contextlib
 import logging
 import os
+import typing
 
 from httpx import _utils
 
 
 @contextlib.contextmanager
-def override_log_level(log_level: str):
+def override_log_level(log_level: str) -> typing.Iterator[None]:
     os.environ["HTTPX_LOG_LEVEL"] = log_level
 
     # Force a reload on the logging handlers
